@@ -1,4 +1,6 @@
 package Ark::Controller::Form;
+use strict;
+use warnings;
 use Ark 'Controller';
 
 with 'Ark::ActionClass::Form';
